
/** Support for win'95 keyboard. 
 *
 * If compiled, it can be enabled/disabled in the .rc file.
 *
 * IceWM assumes the following keyboard mappings:
 *
 * xmodmap - <<EOF
 * ! Left Window key
 * keycode 115 = Meta_L
 * ! Right Window key
 * keycode 116 = Meta_R
 * ! Menu key
 * keycode 117 = Menu
 * EOF
 *
 */
#define MAIL_SPOOL "/var/spool/mail/"       /* '/' terminated ! */

/** Use Linux 2.0 Penguin as start button */
#ifndef START_PIXMAP
#define START_PIXMAP "linux.xpm"
//#define START_PIXMAP "bsd-daemon.xpm"
//#define START_PIXMAP "start.xpm"
//#define START_PIXMAP "xfree86os2.xpm"
#endif

/** Show title bars at the bottom of the window */
#undef TITLEBAR_BOTTOM

/** No not include configurability of options */
#undef NO_CONFIGURE

/** Do not include configurable menus */
#undef NO_CONFIGURE_MENUS

/** No configurable window options */
#undef NO_WINDOW_OPTIONS

/* experimental: broadcast various gui events (for icesound) */
#undef CONFIG_GUIEVENTS

/* tooltips */
#define CONFIG_TOOLTIP

/* taskbar */
#define CONFIG_TASKBAR

/* mailbox */
#define CONFIG_MAILBOX

/* clock */
#define CONFIG_CLOCK

/* start menu */
#define CONFIG_START

/* window list (not menu) */
#define CONFIG_WINLIST

/* TODO */
#define CONFIG_WORKSPACES
#define CONFIG_MWMHINTS
#define CONFIG_APPICONS
#define CONFIG_DESKTOP_ICONS
#define CONFIG_CLOCK_PRETTY

#define CONFIG_DEFAULT_LOOK lookNice
#define CONFIG_DEFAULT_THEME "nice/default.theme"

#define CONFIG_LOOK_NICE
#define CONFIG_LOOK_WARP3
#define CONFIG_LOOK_WIN95
#define CONFIG_LOOK_WARP4
#define CONFIG_LOOK_MOTIF
#define CONFIG_LOOK_PIXMAP
#define CONFIG_LOOK_METAL
#define CONFIG_LOOK_GTK

#define PRETTY_CLOCK
